componenttools.yield_components_grouped_by_duration
===================================================

.. autofunction:: abjad.tools.componenttools.yield_components_grouped_by_duration.yield_components_grouped_by_duration
   :noindex:
